==> haskell-cryptohash-sha1-0.11.100.1-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cryptohash-sha1.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash-sha1
version: 0.11.100.1
id: cryptohash-sha1-0.11.100.1-Edd5keIcG8RLy8uxn1ueOe
key: cryptohash-sha1-0.11.100.1-Edd5keIcG8RLy8uxn1ueOe
license: BSD-3-Clause
copyright: Vincent Hanquez, Herbert Valerio Riedel
maintainer: Herbert Valerio Riedel <hvr@gnu.org>
homepage: https://github.com/hvr/cryptohash-sha1
synopsis: Fast, pure and practical SHA-1 implementation
description:
    A practical incremental and one-pass, pure API to the
    <https://en.wikipedia.org/wiki/SHA-1 SHA-1 hash algorithm>
    (including <https://en.wikipedia.org/wiki/HMAC HMAC> support)
    with performance close to the fastest implementations available in other languages.
    .
    The implementation is made in C with a haskell FFI wrapper that hides the C implementation.
    .
    NOTE: This package has been forked off @cryptohash-0.11.7@ because the @cryptohash@ package has been
    deprecated and so this package continues to satisfy the need for a lightweight package
    providing the SHA1 hash algorithm without any dependencies on packages other than
    @base@ and @bytestring@.
    .
    Consequently, this package can be used as a drop-in replacement for @cryptohash@'\''s
    "Crypto.Hash.SHA1" module, though with a clearly smaller footprint.
category: Data, Cryptography
abi: afb3380b25ce679d1843c0e409adf53b
exposed: True
exposed-modules:
    Crypto.Hash.SHA1
import-dirs: /usr/lib/ghc-8.4.3/site-local/cryptohash-sha1-0.11.100.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/cryptohash-sha1-0.11.100.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/cryptohash-sha1-0.11.100.1
hs-libraries: HScryptohash-sha1-0.11.100.1-Edd5keIcG8RLy8uxn1ueOe
depends:
    base-4.11.1.0 bytestring-0.10.8.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
haddock-interfaces: /usr/share/doc/haskell-cryptohash-sha1/html/cryptohash-sha1.haddock
haddock-html: /usr/share/doc/haskell-cryptohash-sha1/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cryptohash-sha1-0.11.100.1-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cryptohash-sha1.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash-sha1
version: 0.11.100.1
id: cryptohash-sha1-0.11.100.1-FedZHhK3zTs7eOQXIrPeso
key: cryptohash-sha1-0.11.100.1-FedZHhK3zTs7eOQXIrPeso
license: BSD-3-Clause
copyright: Vincent Hanquez, Herbert Valerio Riedel
maintainer: Herbert Valerio Riedel <hvr@gnu.org>
homepage: https://github.com/hvr/cryptohash-sha1
synopsis: Fast, pure and practical SHA-1 implementation
description:
    A practical incremental and one-pass, pure API to the
    <https://en.wikipedia.org/wiki/SHA-1 SHA-1 hash algorithm>
    (including <https://en.wikipedia.org/wiki/HMAC HMAC> support)
    with performance close to the fastest implementations available in other languages.
    .
    The implementation is made in C with a haskell FFI wrapper that hides the C implementation.
    .
    NOTE: This package has been forked off @cryptohash-0.11.7@ because the @cryptohash@ package has been
    deprecated and so this package continues to satisfy the need for a lightweight package
    providing the SHA1 hash algorithm without any dependencies on packages other than
    @base@ and @bytestring@.
    .
    Consequently, this package can be used as a drop-in replacement for @cryptohash@'\''s
    "Crypto.Hash.SHA1" module, though with a clearly smaller footprint.
category: Data, Cryptography
abi: ade62932f4eb5918d1930dd7f2e5584c
exposed: True
exposed-modules:
    Crypto.Hash.SHA1
import-dirs: /usr/lib/ghc-8.6.1/site-local/cryptohash-sha1-0.11.100.1
library-dirs: /usr/lib/ghc-8.6.1/site-local/cryptohash-sha1-0.11.100.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/cryptohash-sha1-0.11.100.1
hs-libraries: HScryptohash-sha1-0.11.100.1-FedZHhK3zTs7eOQXIrPeso
depends:
    base-4.12.0.0 bytestring-0.10.8.2
haddock-interfaces: /usr/share/doc/haskell-cryptohash-sha1/html/cryptohash-sha1.haddock
haddock-html: /usr/share/doc/haskell-cryptohash-sha1/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
